大规模复杂环境下基于统一线性参数模型的多旋翼运动规划

Multi-rotor Motion Planning in Large-scale and Cluttered Environments Based on Unified Linear Parametric Models

  • 摘要: 针对大规模复杂环境下多旋翼无人机路径规划面临的地图存储压力大、实时性差等问题,提出一种高效路径规划方法。首先,通过随机映射方法(RMM)将栅格占据状态构建任务转化为分类任务,以学习仅存储参数向量的连续隐式线性模型,从而实现毫秒级的环境快速查询。其次,针对传统~Kinodynamic A*算法仅考虑几何距离导致搜索效率不足的问题,提出以占据变化率为核心的启发式函数。与传统方法不同,本方法利用环境梯度信息提前识别并规避高风险区域,减少无效节点的扩展。最后,提出一种闭式解~ESDF(欧几里得符号距离场)方法,通过将空间坐标到障碍物距离的映射转化为~RMM回归任务,实现~ESDF的解析表达,避免了传统插值计算的复杂性和分辨率限制,显著提升了距离场构建效率与精度。仿真结果表明,所提方法在不同分辨率(0.3、0.2、0.1 m)下,相比传统~Kinodynamic A*算法,搜索时间平均减少约79.73%,访问节点数量平均降低23.69%;ESDF构建时间缩短超过99%。实际飞行试验进一步验证了方法的高效性与鲁棒性。

     

    Abstract: In response to the challenges of large storage requirements and poor real-time performance faced by path planning for multirotor UAVs (unmanned aerial vehicles) in cluttered, large-scale environments, an efficient path planning method is proposed. Firstly, grid occupancy state construction is transformed into a classification task by the random mapping method (RMM), and thus a continuous implicit linear model storing only the parameter vector is learned, enabling millisecond-level rapid environmental queries. Secondly, a heuristic function centered on the occupancy change rate is introduced to solve the problems of traditional Kinodynamic A* algorithms, such as poor search efficiency caused by only considering geometric distances. Unlike traditional methods, the proposed method utilizes environmental gradient information to preemptively identify and avoid high-risk areas, reducing the expansion of ineffective nodes. Finally, a closed-form ESDF (Euclidean signed distance field) method is proposed, transforming the mapping of spatial coordinates to obstacle distances into an RMM regression task, achieving an analytical expression for the ESDF and avoiding the clutteredness and resolution limitations of traditional interpolation calculations, which significantly enhances the efficiency and accuracy of distance field construction. Simulation results show that the proposed method reduces the search time by an average of 79.73% and lowers the number of accessed nodes by 23.69% across different resolutions (0.3, 0.2, 0.1 m) compared to the traditional Kinodynamic A* algorithm; ESDF construction time is reduced by over 99%. Actual flight tests further validate the efficiency and robustness of the proposed method.

     

/

返回文章
返回